@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2018-2020- Swiss Data Science Center (SDSC)
+# Copyright 2018-2021- Swiss Data Science Center (SDSC)
 # A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
 # Eidgenössische Technische Hochschule Zürich (ETHZ).
 #
@@ -59,7 +59,7 @@ In this situation, you can do effectively two things:
 
   .. code-block:: console
 
-     $ renku update
+     $ renku update --all
 
 .. note:: If there were uncommitted changes then the command fails.
    Check :program:`git status` to see details.
@@ -117,79 +117,23 @@ The following commands will produce the same result.
 
 """
 
-import sys
-import uuid
-
 import click
-from git import Actor
 
-from renku.core.commands.client import pass_local_client
-from renku.core.commands.cwl_runner import execute
-from renku.core.commands.graph import Graph, _safe_path
+from renku.cli.utils.callback import ClickCallback
 from renku.core.commands.options import option_siblings
-from renku.core.models.locals import with_reference
-from renku.core.models.provenance.activities import ProcessRun, WorkflowRun
-from renku.core.models.workflow.converters.cwl import CWLConverter
-from renku.version import __version__, version_url
+from renku.core.commands.update import update_workflows
 
 
 @click.command()
 @click.option("--revision", default="HEAD")
 @click.option("--no-output", is_flag=True, default=False, help="Display commands without output files.")
+@click.option("--all", "-a", "update_all", is_flag=True, default=False, help="Update all outdated files.")
 @option_siblings
 @click.argument("paths", type=click.Path(exists=True, dir_okay=True), nargs=-1)
-@pass_local_client(
-    clean=True, requires_migration=True, commit=True,
-)
-def update(client, revision, no_output, siblings, paths):
+def update(revision, no_output, update_all, siblings, paths):
     """Update existing files by rerunning their outdated workflow."""
-    graph = Graph(client)
-    outputs = graph.build(revision=revision, can_be_cwl=no_output, paths=paths)
-    outputs = {node for node in outputs if graph.need_update(node)}
-    if not outputs:
-        click.secho("All files were generated from the latest inputs.", fg="green")
-        sys.exit(0)
+    communicator = ClickCallback()
 
-    # Check or extend siblings of outputs.
-    outputs = siblings(graph, outputs)
-    output_paths = {node.path for node in outputs if _safe_path(node.path)}
-
-    # Get all clean nodes.
-    input_paths = {node.path for node in graph.nodes} - output_paths
-
-    # Store the generated workflow used for updating paths.
-    workflow = graph.as_workflow(input_paths=input_paths, output_paths=output_paths, outputs=outputs,)
-
-    wf, path = CWLConverter.convert(workflow, client)
-    # Don't compute paths if storage is disabled.
-    if client.check_external_storage():
-        # Make sure all inputs are pulled from a storage.
-        paths_ = (i.consumes.path for i in workflow.inputs)
-        client.pull_paths_from_storage(*paths_)
-
-    execute(client, path, output_paths=output_paths)
-
-    paths = [o.produces.path for o in workflow.outputs]
-
-    client.repo.git.add(*paths)
-
-    if client.repo.is_dirty():
-        commit_msg = "renku update: committing {} newly added files".format(len(paths))
-
-        committer = Actor("renku {0}".format(__version__), version_url)
-
-        client.repo.index.commit(
-            commit_msg, committer=committer, skip_hooks=True,
-        )
-
-    workflow_name = "{0}_update.yaml".format(uuid.uuid4().hex)
-
-    path = client.workflow_path / workflow_name
-
-    workflow.update_id_and_label_from_commit_path(client, client.repo.head.commit, path)
-
-    with with_reference(path):
-        cls = WorkflowRun if workflow.subprocesses else ProcessRun
-        run = cls.from_run(run=workflow, client=client, path=path, update_commits=True)
-        run.to_yaml()
-        client.add_to_activity_index(run)
+    update_workflows().with_communicator(communicator).build().execute(
+        revision=revision, no_output=no_output, update_all=update_all, siblings=siblings, paths=paths
+    )
