@@ -62,7 +62,7 @@ def _list_datasets(client, revision=None, format=None, columns=None):
 
 def list_datasets():
     """Command for listing datasets."""
-    return Command().command(_list_datasets).lock_dataset()
+    return Command().command(_list_datasets)
 
 
 def create_dataset_helper(
@@ -202,6 +202,7 @@ def _add_to_dataset(
     all_at_once=False,
     destination_names=None,
     total_size=None,
+    repository=None,
 ):
     """Add data to a dataset."""
     if len(urls) == 0:
@@ -240,6 +241,7 @@ def _add_to_dataset(
                 extract=extract,
                 all_at_once=all_at_once,
                 destination_names=destination_names,
+                repository=repository,
             )
             if with_metadata:
                 # dataset has the correct list of files
@@ -288,7 +290,7 @@ def _list_files(client, datasets=None, creators=None, include=None, exclude=None
 
 def list_files():
     """Command for listing dataset files."""
-    return Command().command(_list_files).lock_dataset()
+    return Command().command(_list_files)
 
 
 def _file_unlink(client, name, include, exclude, yes=False):
@@ -440,7 +442,7 @@ def _export_dataset(client, name, provider_name, publish, tag, **kwargs):
 
 def export_dataset():
     """Command for exporting a dataset to 3rd party provider."""
-    command = Command().command(_export_dataset).lock_dataset()
+    command = Command().command(_export_dataset)
     return command.require_migration().require_clean()
 
 
@@ -463,7 +465,7 @@ def _import_dataset(
                 tabulate(
                     files,
                     headers=OrderedDict(
-                        (("checksum", None), ("filename", "name"), ("size_in_mb", "size (mb)"), ("filetype", "type"),)
+                        (("checksum", None), ("filename", "name"), ("size_in_mb", "size (mb)"), ("filetype", "type"))
                     ),
                     floatfmt=".2f",
                 )
@@ -548,6 +550,7 @@ def _import_dataset(
             with_metadata=dataset,
             create=not previous_dataset,
             overwrite=True,
+            repository=record.repository,
         )
 
         if previous_dataset:
@@ -813,7 +816,7 @@ def _list_tags(client, name, format):
 
 def list_tags():
     """Command for listing a dataset's tags."""
-    return Command().command(_list_tags).lock_dataset()
+    return Command().command(_list_tags)
 
 
 def _prompt_access_token(exporter):
