@@ -140,7 +140,7 @@ class GitCore:
         repo_path = self.repo.working_dir
         return [
             os.path.join(repo_path, path)
-            for path in itertools.chain((x[0] for x in self.repo.index.entries), self.repo.untracked_files,)
+            for path in itertools.chain((x[0] for x in self.repo.index.entries), self.repo.untracked_files)
         ]
 
     def find_ignored_paths(self, *paths):
@@ -347,9 +347,7 @@ class GitCore:
             pass
 
         # Ignore pre-commit hooks since we have already done everything.
-        self.repo.index.commit(
-            commit_message, committer=committer, skip_hooks=True,
-        )
+        self.repo.index.commit(commit_message, committer=committer, skip_hooks=True)
 
     @contextmanager
     def transaction(
@@ -378,9 +376,7 @@ class GitCore:
             yield self
 
     @contextmanager
-    def worktree(
-        self, path=None, branch_name=None, commit=None, merge_args=("--ff-only",),
-    ):
+    def worktree(self, path=None, branch_name=None, commit=None, merge_args=("--ff-only",)):
         """Create new worktree."""
         from git import NULL_TREE, GitCommandError
 
