@@ -36,7 +36,7 @@ class Association:
     """Assign responsibility to an agent for an activity."""
 
     plan = attr.ib()
-    agent = attr.ib(default=None,)
+    agent = attr.ib(default=None)
 
     _id = attr.ib(kw_only=True)
 
@@ -48,7 +48,7 @@ class Association:
         agent = SoftwareAgent.from_commit(activity.commit)
         return cls(
             plan=activity.__association_cls__(
-                commit=commit or activity.commit, client=activity.client, path=activity.path, activity=activity,
+                commit=commit or activity.commit, client=activity.client, path=activity.path, activity=activity
             ),
             agent=agent,
             id=activity._id + "/association",  # add plan and agent
@@ -123,7 +123,7 @@ class Generation(EntityProxyMixin):
     role = attr.ib(default=None)
 
     _activity = attr.ib(
-        default=None, kw_only=True, converter=lambda value: weakref.ref(value) if value is not None else None,
+        default=None, kw_only=True, converter=lambda value: weakref.ref(value) if value is not None else None
     )
     _id = attr.ib(kw_only=True)
 
