@@ -22,12 +22,16 @@ from pathlib import Path
 
 import pkg_resources
 
+# TODO: #2100 the git access error should have its own error code
 GIT_ACCESS_DENIED_ERROR_CODE = -32000
 GIT_UNKNOWN_ERROR_CODE = -32001
 
 RENKU_EXCEPTION_ERROR_CODE = -32100
 REDIS_EXCEPTION_ERROR_CODE = -32200
 
+# TODO: #2100 according to the JSON-RPC spec this code is reserved for "method not
+# found" - the invalid headers code should either be a custom code or lumped
+# under invalid params code
 INVALID_HEADERS_ERROR_CODE = -32601
 INVALID_PARAMS_ERROR_CODE = -32602
 INTERNAL_FAILURE_ERROR_CODE = -32603
@@ -66,5 +70,7 @@ SERVICE_PREFIX = os.getenv("CORE_SERVICE_PREFIX", "/")
 SERVICE_API_BASE_PATH = os.getenv("CORE_SERVICE_API_BASE_PATH", "/")
 # path to the swagger spec
 API_SPEC_URL = SERVICE_PREFIX.lstrip("/") + "/spec.json"
+# URL for fetching the OIDC configuration
+OIDC_URL = os.getenv("OIDC_URL", "/auth/realms/Renku/.well-known/openid-configuration")
 
 LOGGER_CONFIG_FILE = Path(pkg_resources.resource_filename("renku", "service/logging.yaml"))
