@@ -16,7 +16,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Renku service cache views."""
-from flask import Blueprint, request
+from flask import request
 
 from renku.service.config import SERVICE_PREFIX
 from renku.service.controllers.cache_files_upload import UploadFilesCtrl
@@ -25,6 +25,7 @@ from renku.service.controllers.cache_list_uploaded import ListUploadedFilesCtrl
 from renku.service.controllers.cache_migrate_project import MigrateProjectCtrl
 from renku.service.controllers.cache_migrations_check import MigrationsCheckCtrl
 from renku.service.controllers.cache_project_clone import ProjectCloneCtrl
+from renku.service.views.api_versions import V0_9, VersionedBlueprint
 from renku.service.views.decorators import (
     accepts_json,
     handle_common_except,
@@ -34,12 +35,10 @@ from renku.service.views.decorators import (
 )
 
 CACHE_BLUEPRINT_TAG = "cache"
-cache_blueprint = Blueprint("cache", __name__, url_prefix=SERVICE_PREFIX)
+cache_blueprint = VersionedBlueprint("cache", __name__, url_prefix=SERVICE_PREFIX)
 
 
-@cache_blueprint.route(
-    "/cache.files_list", methods=["GET"], provide_automatic_options=False,
-)
+@cache_blueprint.route("/cache.files_list", methods=["GET"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @requires_cache
 @requires_identity
@@ -62,9 +61,7 @@ def list_uploaded_files_view(user_data, cache):
     return ListUploadedFilesCtrl(cache, user_data).to_response()
 
 
-@cache_blueprint.route(
-    "/cache.files_upload", methods=["POST"], provide_automatic_options=False,
-)
+@cache_blueprint.route("/cache.files_upload", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @requires_cache
 @requires_identity
@@ -75,10 +72,18 @@ def upload_file_view(user_data, cache):
     ---
     post:
       description: Upload a file or archive of files.
+      parameters:
+        - in: query
+          schema: FileUploadRequest
       requestBody:
         content:
-          application/json:
-            schema: FileUploadRequest
+          multipart/form-data:
+            schema:
+              type: object
+              properties:
+                file:
+                  type: string
+                  format: binary
       responses:
         200:
           description: List of uploaded files.
@@ -91,9 +96,7 @@ def upload_file_view(user_data, cache):
     return UploadFilesCtrl(cache, user_data, request).to_response()
 
 
-@cache_blueprint.route(
-    "/cache.project_clone", methods=["POST"], provide_automatic_options=False,
-)
+@cache_blueprint.route("/cache.project_clone", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -122,9 +125,7 @@ def project_clone_view(user_data, cache):
     return ProjectCloneCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@cache_blueprint.route(
-    "/cache.project_list", methods=["GET"], provide_automatic_options=False,
-)
+@cache_blueprint.route("/cache.project_list", methods=["GET"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @requires_cache
 @requires_identity
@@ -147,9 +148,7 @@ def list_projects_view(user_data, cache):
     return ListProjectsCtrl(cache, user_data).to_response()
 
 
-@cache_blueprint.route(
-    "/cache.migrate", methods=["POST"], provide_automatic_options=False,
-)
+@cache_blueprint.route("/cache.migrate", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @handle_migration_except
 @accepts_json
@@ -178,9 +177,7 @@ def migrate_project_view(user_data, cache):
     return MigrateProjectCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@cache_blueprint.route(
-    "/cache.migrations_check", methods=["GET"], provide_automatic_options=False,
-)
+@cache_blueprint.route("/cache.migrations_check", methods=["GET"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @requires_cache
 @requires_identity
@@ -192,6 +189,9 @@ def migration_check_project_view(user_data, cache):
     ---
     get:
       description: Retrieve migration information for a project.
+      parameters:
+        - in: query
+          schema: ProjectMigrationCheckRequest
       responses:
         200:
           description: Information about required migrations for the project.
