@@ -16,7 +16,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Renku service project clone tests."""
-import os
 import time
 import uuid
 
@@ -25,7 +24,8 @@ from flaky import flaky
 from marshmallow import EXCLUDE
 
 from renku.service.controllers.utils.project_clone import user_project_clone
-from renku.service.serializers.templates import ManifestTemplatesRequest
+from renku.service.serializers.templates import ProjectTemplateRequest
+from tests.utils import modified_environ
 
 
 @pytest.mark.integration
@@ -36,38 +36,40 @@ def test_service_user_project_clone(svc_client_cache):
 
     user_data = {
         "user_id": uuid.uuid4().hex,
-        "email": "contact@justsam.io",
+        "email": "contact@renkulab.io",
         "fullname": "renku the frog",
         "token": "None",
     }
     project_data = {
-        "name": "renku-project-template",
+        "project_name": "deadbeef",
+        "project_repository": "https://dev.renku.ch",
+        "project_namespace": "gitlab/renku-qa",
+        "identifier": "0xdeadbeef",
         "depth": 1,
         "url": "https://github.com/SwissDataScienceCenter/renku-project-template",
         "owner": "SwissDataScienceCenter",
     }
 
-    project_data = ManifestTemplatesRequest().load({**user_data, **project_data}, unknown=EXCLUDE)
+    project_data = ProjectTemplateRequest().load({**user_data, **project_data}, unknown=EXCLUDE)
     project_one = user_project_clone(user_data, project_data)
     assert project_one.age >= 0
     assert not project_one.ttl_expired()
     assert project_one.exists()
     old_path = project_one.abs_path
 
-    os.environ["RENKU_SVC_CLEANUP_TTL_PROJECTS"] = "1"
-    time.sleep(1)
-    assert project_one.ttl_expired()
+    with modified_environ(RENKU_SVC_CLEANUP_TTL_PROJECTS="1"):
+        time.sleep(1)
+        assert project_one.ttl_expired()
 
-    os.environ["RENKU_SVC_CLEANUP_TTL_PROJECTS"] = "3600"
+    with modified_environ(RENKU_SVC_CLEANUP_TTL_PROJECTS="3600"):
+        project_two = user_project_clone(user_data, project_data)
+        assert project_two.age >= 0
+        assert not project_two.ttl_expired()
+        assert project_two.exists()
 
-    project_two = user_project_clone(user_data, project_data)
-    assert project_two.age >= 0
-    assert not project_two.ttl_expired()
-    assert project_two.exists()
-
-    new_path = project_two.abs_path
-    assert old_path != new_path
-    user = cache.get_user(user_data["user_id"])
-    projects = [project.project_id for project in cache.get_projects(user)]
-    assert project_one.project_id in projects
-    assert project_two.project_id in projects
+        new_path = project_two.abs_path
+        assert old_path != new_path
+        user = cache.get_user(user_data["user_id"])
+        projects = [project.project_id for project in cache.get_projects(user)]
+        assert project_one.project_id in projects
+        assert project_two.project_id in projects
