@@ -17,6 +17,7 @@
 # limitations under the License.
 """Renku service version view tests."""
 from renku.core.management.migrate import SUPPORTED_PROJECT_VERSION
+from renku.service.views.api_versions import MAXIMUM_VERSION, MINIMUM_VERSION
 
 
 def test_version(svc_client):
@@ -27,6 +28,22 @@ def test_version(svc_client):
     assert "result" in response.json
     data = response.json["result"]
 
-    assert {"latest_version", "supported_project_version"} == set(data.keys())
+    assert {"latest_version", "supported_project_version", "minimum_api_version", "maximum_api_version"} == set(
+        data.keys()
+    )
     assert __version__ == data["latest_version"]
     assert SUPPORTED_PROJECT_VERSION == data["supported_project_version"]
+    assert MINIMUM_VERSION.name == data["minimum_api_version"]
+    assert MAXIMUM_VERSION.name == data["maximum_api_version"]
+
+    response = svc_client.get("/0.9/version")
+    assert "result" in response.json
+    data = response.json["result"]
+
+    assert {"latest_version", "supported_project_version", "minimum_api_version", "maximum_api_version"} == set(
+        data.keys()
+    )
+    assert __version__ == data["latest_version"]
+    assert SUPPORTED_PROJECT_VERSION == data["supported_project_version"]
+    assert MINIMUM_VERSION.name == data["minimum_api_version"]
+    assert MAXIMUM_VERSION.name == data["maximum_api_version"]
